pub struct PatternMatch {
pub pattern_name: String,
pub matched_actions: Vec<usize>,
pub confidence: f64,
pub severity: SecuritySeverity,
pub time_span: Duration,
}Expand description
A matched attack pattern with supporting evidence.
Fields
pattern_name: StringName of the matched pattern.
matched_actions: Vec<usize>Indices into the session history of the actions that matched each step.
confidence: f64Confidence score for this match.
severity: SecuritySeveritySeverity of the matched pattern.
time_span: DurationTime span between the first and last matched action.